traitsui\.default\_dock\_window\_theme module
=============================================

.. automodule:: traitsui.default_dock_window_theme
    :members:
    :undoc-members:
    :show-inheritance:
